import io
import json
import logging
import oci
import re
from oci.dns.models import UpdateRRSetDetails, RecordDetails

#
# Create by joao.tarla@oracle.com in 2024-Jun-13
#

def get_dns_zones_and_regions(private_zoned_ocid_list):
    # Split the comma-separated list into individual OCIDs
    ocids = private_zoned_ocid_list.split(',')
    target_dns_zones = []

    # Iterate over each OCID
    for ocid in ocids:
        # Strip any leading/trailing whitespace
        ocid = ocid.strip()

        # Extract the region from the OCID
        try:
            region = ocid.split('.')[3]
        except IndexError:
            print(f"Invalid OCID format: {ocid}")
            continue

        # Print the OCID and the extracted region
        target_dns_zones.append({'OCID': ocid, 'REGION': region})  
    return target_dns_zones    



def extract_domain(url):
    pattern = r'\.(.*\..*)$'
    match = re.search(pattern, url)
    if match:
        domain = match.group(1)
        return(domain)
    else:
        return("ERROR")

def getInstanceData(compute_client, network_client, instance_id, compartment_id):
    host_list = []
    vnic_attachments = compute_client.list_vnic_attachments(compartment_id, instance_id=instance_id).data
    hostname = compute_client.get_instance(instance_id=instance_id).data.display_name
    # Identify the DOMAIN from private Zone
    #domainPz = dns_client.get_zone(zone_name_or_id=private_zone_ocid).data.name
    #print(domainPz)

    for vnic_attachment in vnic_attachments:
        vnic = network_client.get_vnic(vnic_attachment.vnic_id).data
        logging.getLogger().info(f"Subnet IP: {vnic.subnet_id}")
        logging.getLogger().info(f"HostName : {hostname} - Private IP: {vnic.private_ip}")        
        add_host(host_list,hostname.upper(),vnic.private_ip)

    return host_list
        
    
def add_host(host_list, hostname, ip):
    host_list.append({'HOSTNAME': hostname, 'IP': ip})

def update_a_record(dns_client, private_zone_ocid, record_name, new_ip):
    
    # Prepare the new A record details
    a_record_details = RecordDetails(
        domain=record_name,
        rtype="A",
        rdata=new_ip,
        ttl=30  # Time to live in seconds
    )

    # Prepare the request to update the record set
    update_rr_set_details = UpdateRRSetDetails(
        items=[a_record_details]
    )

    # Update the A record in the specified zone
    response = dns_client.update_rr_set(
        zone_name_or_id=private_zone_ocid,
        domain=record_name,
        rtype="A",
        update_rr_set_details=update_rr_set_details
    )

    return response
